# External Flash Loader for ST-Link Utility and STM32CubeProgrammer

## Overview

This code implements an external flash loader for an Issy IS25LP128 Flash memory. 
The IS25LP128 is a 128Mbit SPI serial flash.
The code should work with other sizes with just minor changes to the device config.

## External Loader

An external loader is an "extension" to the programming tool, making it possible to read, write and erase an 
external SPI (or I2C or similar) flash/eeprom memory directly from the programmer.
This way, complete filesystems or other constants can be pre-loaded in a flash for use by the application.


## Hardware dependency

The code is obviously quite dependant on the hardware configuration, pinouts e.t.c.
This implementation was made for a board with an STM32F769NI CPU, using the QSPI lines.
The GPIO assingment could easily be changed to match a different pinout or GPIO mapping.


## This code

The code is based on various other external loaders, but have been stripped of most HAL code as ST's HAL code is terribly  bloated and unpredictable.
Still, a few of the HAL headers are needed for constants, which causes the code to compile a part of the HAL, but the resulting code is not included in the final image.
I might clean this up a bit more in the future.
The origin of this code is coming from https://github.com/magicmicros/AT25Q641_ExternalLoader.git and has been adopted to emStamp-Neon, resp. emSBC-Neon comint from emtrion GmbH.

### Building

The loader is built with a makefile, located in the directory Release. There is a dependency on the tool chain, which has to be modified before building.

### Testing
The loader has been tested with STM32CubeIDE, version 1.4.0 and version 1.5.0, and STM32 ST-Link Utility, version v4.6.0., both running on Win10.

For STM32CubeIDE the loader IS25LP128_ExternalLoader.stldr has to be copied to:
c:\ST\STM32CubeIDE_1.4.0\STM32CubeIDE\plugins\com.st.stm32cube.ide.mcu.externaltools.cubeprogrammer.win32_1.4.0.202007081208\tools\bin\ExternalLoader\
resp.
c:\ST\STM32CubeIDE_1.4.0\STM32CubeIDE\plugins\com.st.stm32cube.ide.mcu.externaltools.cubeprogrammer.win32_1.5.0.202011040924\tools\bin\ExternalLoader\
when preinstalled ide has been upgraded to 1.5.0

and for STM32 ST-Link Utility the loader has to be copied to
c:\Program Files (x86)\STMicroelectronics\STM32 ST-LINK Utility\ST-LINK Utility\ExternalLoader\

Dr. Frank Reither, emtrion GmbH
